import React, { useRef, useEffect, useState } from 'react';
import mapboxgl from 'mapbox-gl';

import { SearchBox } from '../src/components/SearchBox';
import { MapboxSearchBox } from '@mapbox/search-js-web';
import { useSearchBoxCore } from '../src';

const ACCESS_TOKEN = MAPBOX_ACCESS_TOKEN;

export function Search(): React.ReactElement {
  const [map, setMap] = useState(null);
  const [value, setValue] = useState('');

  const sbRef = useRef(null);

  const mapContainerRef = useRef(null);

  const searchBoxCore = useSearchBoxCore({
    accessToken: ACCESS_TOKEN
  });

  const runSearchBoxSuggest = React.useCallback(async () => {
    const response = await searchBoxCore.suggest('1600 pennsylvania ave nw', {
      sessionToken: 'test-123'
    });
    console.log(response);
  }, [searchBoxCore]);

  useEffect(() => {
    mapboxgl.accessToken = ACCESS_TOKEN;

    const map = new mapboxgl.Map({
      container: mapContainerRef.current,
      style: 'mapbox://styles/mapbox/streets-v11',
      center: [-73.943, 40.7789],
      zoom: 11
    });

    setMap(map);

    map.addControl(new mapboxgl.FullscreenControl());

    const mapSearchControl = new MapboxSearchBox();
    mapSearchControl.accessToken = ACCESS_TOKEN;
    mapSearchControl.componentOptions = {
      allowReverse: true,
      flipCoordinates: false
    };
    mapSearchControl.mapboxgl = mapboxgl;
    mapSearchControl.marker = { color: 'orange' };
    map.addControl(mapSearchControl);

    // sbRef.current.search('central park, new york ny');

    // Clean up on unmount
    return () => map.remove();
  }, []);

  return (
    <div
      style={{
        height: '600px',
        width: '100%',
        margin: '30px',
        display: 'flex',
        flexDirection: 'column'
      }}
    >
      <div style={{ margin: '24px 12px' }}>
        <SearchBox
          accessToken={ACCESS_TOKEN}
          value={value}
          placeholder="Search for an address"
          onChange={(v) => {
            setValue(v);
            console.log('change', v);
          }}
          onSuggest={(res) => console.log('suggest', res)}
          onSuggestError={(err) => console.log('error', err)}
          onRetrieve={(res) => console.log('retrieve', res)}
          onClear={() => console.log('clear')}
          map={map}
          marker={true}
          mapboxgl={mapboxgl}
          ref={sbRef}
          options={{ language: 'es', types: 'country,poi' }}
          componentOptions={{
            allowReverse: true,
            flipCoordinates: true
          }}
        />
      </div>
      <br></br>
      <div
        className="map-container"
        style={{ height: '100%', width: '100%' }}
        ref={mapContainerRef}
      />
      <button type="button" onClick={runSearchBoxSuggest}>
        useSearchBoxCore Test
      </button>
    </div>
  );
}
